@@ -3,7 +3,7 @@
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2017,2018 Slaven Rezic. All rights reserved.
+# Copyright (C) 2017,2018,2022 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -15,15 +15,14 @@ package Doit::Brew; # Convention: all commands here should be prefixed with 'bre
 
 use strict;
 use warnings;
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 sub new { bless {}, shift }
 sub functions { qw(brew_install_packages brew_missing_packages can_brew) }
-sub add_component { qw(extcmd) }
 
 sub can_brew {
-    require Doit::Extcmd;
-    Doit::Extcmd::is_in_path('brew') ? 1 : 0;
+    my($self) = @_;
+    $self->which('brew') ? 1 : 0;
 }
 
 sub brew_install_packages {
